@@ -149,10 +149,13 @@ def getPNLValueWithTimestamp(ts, pnl: trdb2py.trading2_pb2.PNLAssetData, isAdd:
 
         return len(pnl.values) - 1
 
-    for i in range(0, len(pnl.values)):
+    i = 0
+    for v in len(pnl.values):
         if ts == pnl.values[i].ts:
             return i
 
+        i = i + 1
+
     return -1
 
 
